import { registerAccountCallbacks } from "./Account/accountSocket";
import { users } from "./Account/users";
import { registerLobbyCallbacks } from "./Lobby/lobbySocket";
import { playerData } from "./Player/playerData";
import { game } from "./game";

const express = require("express");
const app = express();
const port = 3000;
const server = require('http').Server(app);

server.listen(port, () => {
  console.log(`Server listening at port ${port}`);
});

const io = require("socket.io")(server, {
	cors: {
        origin: '*',
        methods: ["GET", "POST"]
    }
});

users.loadUsers();

io.on('connection', (socket) => {
	console.log("Got connection!");
	socket.emit("connectSuccess", "");

    registerAccountCallbacks(socket);
    registerLobbyCallbacks(socket);
    
    socket.io = io;

    socket.on("disconnect", () => {
        socket.disconnect()
        let idx = game.lobbyState.players.findIndex((pl) => pl.socketId == socket.id)
        if(idx != -1){
            game.lobbyState.players.splice(idx, 1)
        }
        delete socket.userId
        console.log(socket.id + " disconnected");
    });

    socket.on('error',function(er){
        console.log(er);
    });
});

//Send player updates to everyone
setInterval(() => {
    let userCount = game.lobbyState.players.length
    if(userCount > 0){
        game.lobbyState.hostSocket = game.lobbyState.players[0].socketId
        io.emit('lobby', JSON.stringify(game.lobbyState))
    }
}, 1000/30)

setInterval(() => {
    console.log("Connected losers: " + game.lobbyState.players.length);
}, 60 * 1000)

process.on('SIGINT', function () {
    console.log('Ctrl-C...');
    process.exit(2);
});
process.on('exit', function () {
    users.saveUsers();
    console.log("exitted");
});